/*---------------------------------------------------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  1.5                                   |
|   \\  /    A nd           | Web:      http://www.openfoam.org               |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/

FoamFile
{
    version         2.0;
    format          ascii;
    class           dictionary;
    object          blockMeshDict;
}

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

// Parametrized test case for the El-Alti Active Flow Control actuator.

//Run using:
//m4 -P blockMeshDict.m4 > blockMeshDict

//m4 definitions:
m4_changecom(//)m4_changequote([,])
m4_define(calc, [m4_esyscmd(perl -e 'use Math::Trig; printf ($1)')])
m4_define(VCOUNT, 0)
m4_define(vlabel, [[// ]Vertex $1 = VCOUNT m4_define($1, VCOUNT)m4_define([VCOUNT], m4_incr(VCOUNT))])

//Mathematical constants:
m4_define(pi, 3.1415926536)

//Geometry
m4_define(boxWidthX,  0.5)
m4_define(boxWidthY,  0.5)
m4_define(slotWidthX,  0.4) //NOTE: slotWidthX < boxWidthX!!!
m4_define(slotWidthY,  0.01) //NOTE: slotWidthY < boxWidthY!!!
m4_define(boxHeight,  0.5)
m4_define(slotHeight,  0.1)
m4_define(ambientHeight,  1)

//Grid points (integers!):
m4_define(slotCellSize, 0.001) //NOTE: A fraction of min(slotWidthX,slotWidthY)
m4_define(slotCellsX, calc(int(slotWidthX/slotCellSize)))
m4_define(slotCellsY, calc(int(slotWidthY/slotCellSize)))
m4_define(outsideSlotCellsX, 12)
m4_define(outsideSlotCellsY, 20)
m4_define(zABnumberOfCells, 20)
m4_define(zBCnumberOfCells, calc(int(slotHeight/slotCellSize)))
m4_define(zCDnumberOfCells, 20)
m4_define(outsideSlotGradingX, calc(1/1.2))
m4_define(outsideSlotGradingY, calc(1/7))
m4_define(boxGrading, calc(1/5))
m4_define(ambientGrading, calc(5))

//Plane A:
m4_define(zA, calc(-boxHeight-slotHeight))

//Plane B:
m4_define(zB, calc(-slotHeight))

//Plane C:
m4_define(zC, 0)

//Plane D:
m4_define(zD, ambientHeight)

convertToMeters 1;

vertices
(
//Plane A:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zA) vlabel(A0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zA) vlabel(A1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zA) vlabel(A2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zA) vlabel(A3)
(calc(-boxWidthX/2) calc(-slotWidthY/2) zA) vlabel(A4)
(calc(-slotWidthX/2) calc(-slotWidthY/2) zA) vlabel(A5)
(calc(slotWidthX/2) calc(-slotWidthY/2) zA) vlabel(A6)
(calc(boxWidthX/2) calc(-slotWidthY/2) zA) vlabel(A7)
(calc(-boxWidthX/2) calc(slotWidthY/2) zA) vlabel(A8)
(calc(-slotWidthX/2) calc(slotWidthY/2) zA) vlabel(A9)
(calc(slotWidthX/2) calc(slotWidthY/2) zA) vlabel(A10)
(calc(boxWidthX/2) calc(slotWidthY/2) zA) vlabel(A11)
(calc(-boxWidthX/2) calc(boxWidthY/2) zA) vlabel(A12)
(calc(-slotWidthX/2) calc(boxWidthY/2) zA) vlabel(A13)
(calc(slotWidthX/2) calc(boxWidthY/2) zA) vlabel(A14)
(calc(boxWidthX/2) calc(boxWidthY/2) zA) vlabel(A15)

//Plane B:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zB) vlabel(B0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zB) vlabel(B1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zB) vlabel(B2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zB) vlabel(B3)
(calc(-boxWidthX/2) calc(-slotWidthY/2) zB) vlabel(B4)
(calc(-slotWidthX/2) calc(-slotWidthY/2) zB) vlabel(B5)
(calc(slotWidthX/2) calc(-slotWidthY/2) zB) vlabel(B6)
(calc(boxWidthX/2) calc(-slotWidthY/2) zB) vlabel(B7)
(calc(-boxWidthX/2) calc(slotWidthY/2) zB) vlabel(B8)
(calc(-slotWidthX/2) calc(slotWidthY/2) zB) vlabel(B9)
(calc(slotWidthX/2) calc(slotWidthY/2) zB) vlabel(B10)
(calc(boxWidthX/2) calc(slotWidthY/2) zB) vlabel(B11)
(calc(-boxWidthX/2) calc(boxWidthY/2) zB) vlabel(B12)
(calc(-slotWidthX/2) calc(boxWidthY/2) zB) vlabel(B13)
(calc(slotWidthX/2) calc(boxWidthY/2) zB) vlabel(B14)
(calc(boxWidthX/2) calc(boxWidthY/2) zB) vlabel(B15)

//Plane C:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zC) vlabel(C0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zC) vlabel(C1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zC) vlabel(C2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zC) vlabel(C3)
(calc(-boxWidthX/2) calc(-slotWidthY/2) zC) vlabel(C4)
(calc(-slotWidthX/2) calc(-slotWidthY/2) zC) vlabel(C5)
(calc(slotWidthX/2) calc(-slotWidthY/2) zC) vlabel(C6)
(calc(boxWidthX/2) calc(-slotWidthY/2) zC) vlabel(C7)
(calc(-boxWidthX/2) calc(slotWidthY/2) zC) vlabel(C8)
(calc(-slotWidthX/2) calc(slotWidthY/2) zC) vlabel(C9)
(calc(slotWidthX/2) calc(slotWidthY/2) zC) vlabel(C10)
(calc(boxWidthX/2) calc(slotWidthY/2) zC) vlabel(C11)
(calc(-boxWidthX/2) calc(boxWidthY/2) zC) vlabel(C12)
(calc(-slotWidthX/2) calc(boxWidthY/2) zC) vlabel(C13)
(calc(slotWidthX/2) calc(boxWidthY/2) zC) vlabel(C14)
(calc(boxWidthX/2) calc(boxWidthY/2) zC) vlabel(C15)

//Plane D:
(calc(-boxWidthX/2) calc(-boxWidthY/2) zD) vlabel(D0)
(calc(-slotWidthX/2) calc(-boxWidthY/2) zD) vlabel(D1)
(calc(slotWidthX/2) calc(-boxWidthY/2) zD) vlabel(D2)
(calc(boxWidthX/2) calc(-boxWidthY/2) zD) vlabel(D3)
(calc(-boxWidthX/2) calc(-slotWidthY/2) zD) vlabel(D4)
(calc(-slotWidthX/2) calc(-slotWidthY/2) zD) vlabel(D5)
(calc(slotWidthX/2) calc(-slotWidthY/2) zD) vlabel(D6)
(calc(boxWidthX/2) calc(-slotWidthY/2) zD) vlabel(D7)
(calc(-boxWidthX/2) calc(slotWidthY/2) zD) vlabel(D8)
(calc(-slotWidthX/2) calc(slotWidthY/2) zD) vlabel(D9)
(calc(slotWidthX/2) calc(slotWidthY/2) zD) vlabel(D10)
(calc(boxWidthX/2) calc(slotWidthY/2) zD) vlabel(D11)
(calc(-boxWidthX/2) calc(boxWidthY/2) zD) vlabel(D12)
(calc(-slotWidthX/2) calc(boxWidthY/2) zD) vlabel(D13)
(calc(slotWidthX/2) calc(boxWidthY/2) zD) vlabel(D14)
(calc(boxWidthX/2) calc(boxWidthY/2) zD) vlabel(D15)
);

// Defining blocks:
blocks
(

    //Blocks between plane A and plane B:
    hex (A0 A1 A5 A4 B0 B1 B5 B4 ) AB
      (outsideSlotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (outsideSlotGradingX outsideSlotGradingY boxGrading)
    hex (A1 A2 A6 A5 B1 B2 B6 B5 ) AB
      (slotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (1 outsideSlotGradingY boxGrading)
    hex (A2 A3 A7 A6 B2 B3 B7 B6 ) AB
      (outsideSlotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) outsideSlotGradingY boxGrading)
    hex (A4 A5 A9 A8 B4 B5 B9 B8 ) AB
      (outsideSlotCellsX slotCellsY zABnumberOfCells)
      simpleGrading (outsideSlotGradingX 1 boxGrading)
    hex (A5 A6 A10 A9 B5 B6 B10 B9 ) AB
      (slotCellsX slotCellsY zABnumberOfCells)
      simpleGrading (1 1 boxGrading)
    hex (A6 A7 A11 A10 B6 B7 B11 B10 ) AB
      (outsideSlotCellsX slotCellsY zABnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) 1 boxGrading)
    hex (A8 A9 A13 A12 B8 B9 B13 B12 ) AB
      (outsideSlotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (outsideSlotGradingX calc(1/outsideSlotGradingY) boxGrading)
    hex (A9 A10 A14 A13 B9 B10 B14 B13 ) AB
      (slotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (1 calc(1/outsideSlotGradingY) boxGrading)
    hex (A10 A11 A15 A14 B10 B11 B15 B14 ) AB
      (outsideSlotCellsX outsideSlotCellsY zABnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) calc(1/outsideSlotGradingY) boxGrading)

    //Blocks between plane B and plane C:
    hex (B5 B6 B10 B9 C5 C6 C10 C9 ) BC
      (slotCellsX slotCellsY zBCnumberOfCells)
      simpleGrading (1 1 1)

    //Blocks between plane C and plane D:
    hex (C0 C1 C5 C4 D0 D1 D5 D4 ) CD
      (outsideSlotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (outsideSlotGradingX outsideSlotGradingY ambientGrading)
    hex (C1 C2 C6 C5 D1 D2 D6 D5 ) CD
      (slotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (1 outsideSlotGradingY ambientGrading)
    hex (C2 C3 C7 C6 D2 D3 D7 D6 ) CD
      (outsideSlotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) outsideSlotGradingY ambientGrading)
    hex (C4 C5 C9 C8 D4 D5 D9 D8 ) CD
      (outsideSlotCellsX slotCellsY zCDnumberOfCells)
      simpleGrading (outsideSlotGradingX 1 ambientGrading)
    hex (C5 C6 C10 C9 D5 D6 D10 D9 ) CD
      (slotCellsX slotCellsY zCDnumberOfCells)
      simpleGrading (1 1 ambientGrading)
    hex (C6 C7 C11 C10 D6 D7 D11 D10 ) CD
      (outsideSlotCellsX slotCellsY zCDnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) 1 ambientGrading)
    hex (C8 C9 C13 C12 D8 D9 D13 D12 ) CD
      (outsideSlotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (outsideSlotGradingX calc(1/outsideSlotGradingY) ambientGrading)
    hex (C9 C10 C14 C13 D9 D10 D14 D13 ) CD
      (slotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (1 calc(1/outsideSlotGradingY) ambientGrading)
    hex (C10 C11 C15 C14 D10 D11 D15 D14 ) CD
      (outsideSlotCellsX outsideSlotCellsY zCDnumberOfCells)
      simpleGrading (calc(1/outsideSlotGradingX) calc(1/outsideSlotGradingY) ambientGrading)

);

edges
(
);

// Defining patches:
patches
(
    patch boxBottom
    (
       (A1 A0 A4 A5)
       (A2 A1 A5 A6)
       (A3 A2 A6 A7)
       (A5 A4 A8 A9)
       (A6 A5 A9 A10)
       (A7 A6 A10 A11)
       (A9 A8 A12 A13)
       (A10 A9 A13 A14)
       (A11 A10 A14 A15)
    )
    patch boxSide
    (
       (A0 A1 B1 B0)
       (A1 A2 B2 B1)
       (A2 A3 B3 B2)

       (A3 A7 B7 B3)
       (A7 A11 B11 B7)
       (A11 A15 B15 B11)

       (A15 A14 B14 B15)
       (A14 A13 B13 B14)
       (A13 A12 B12 B13)

       (A12 A8 B8 B12)
       (A8 A4 B4 B8)
       (A4 A0 B0 B4)
    )
    wall boxTop
    (
       (B5 B4 B0 B1)
       (B6 B5 B1 B2)
       (B7 B6 B2 B3)
       (B9 B8 B4 B5)
       (B11 B10 B6 B7)
       (B13 B12 B8 B9)
       (B14 B13 B9 B10)
       (B15 B14 B10 B11)
    )
    wall slotSide
    (
       (B5 B6 C6 C5)
       (B6 B10 C10 C6)
       (B10 B9 C9 C10)
       (B9 B5 C5 C9)
    )
    wall ambientBottom
    (
       (C1 C0 C4 C5)
       (C2 C1 C5 C6)
       (C3 C2 C6 C7)
       (C5 C4 C8 C9)
       (C7 C6 C10 C11)
       (C9 C8 C12 C13)
       (C10 C9 C13 C14)
       (C11 C10 C14 C15)
    )
    patch ambientSide
    (
       (C0 C1 D1 D0)
       (C1 C2 D2 D1)
       (C2 C3 D3 D2)

       (C3 C7 D7 D3)
       (C7 C11 D11 D7)
       (C11 C15 D15 D11)

       (C15 C14 D14 D15)
       (C14 C13 D13 D14)
       (C13 C12 D12 D13)

       (C12 C8 D8 D12)
       (C8 C4 D4 D8)
       (C4 C0 D0 D4)
    )
    patch ambientTop
    (
       (D5 D4 D0 D1)
       (D6 D5 D1 D2)
       (D7 D6 D2 D3)
       (D9 D8 D4 D5)
       (D10 D9 D5 D6)
       (D11 D10 D6 D7)
       (D13 D12 D8 D9)
       (D14 D13 D9 D10)
       (D15 D14 D10 D11)
    )
);

mergePatchPairs 
(
);

// ************************************************************************* //
